@@ -22,7 +22,6 @@
 #include <KIO/DeleteJob>
 #include <KIO/CopyJob>
 #include <KSharedConfig>
-#include <KNSCore/DownloadManager>
 
 #include <QStringList>
 #include <QUrl>
@@ -91,7 +90,7 @@ void Theme_Config::loadSettings()
         // initialize index counter
         int i = 0;
         // iterate through all found theme directories
-        for (const QString& dir : qAsConst(m_dirs)) {
+        for (const QString& dir : std::as_const(m_dirs)) {
             KDesktopFile themeRC(dir);
             // get the name and comment from the theme
             themeName = themeRC.readName();
@@ -150,7 +149,7 @@ void Theme_Config::saveSettings()
         {
             // save icon theme name
             KSharedConfigPtr config = KSharedConfig::openConfig();
-            KConfigGroup grp = config->group("Themes");
+            KConfigGroup grp = config->group(QStringLiteral("Themes"));
             grp.writeEntry("IconTheme",m_currentTheme);
             // set in-memory theme to the saved theme
             Preferences::self()->setIconTheme(m_currentTheme);
@@ -195,7 +194,7 @@ void Theme_Config::installTheme()
         tmpFile.close(); // no need to keep the file open, it isn't deleted until the destructor is called
 
         QUrl tmpUrl = QUrl::fromLocalFile(tmpFile.fileName());
-        KIO::FileCopyJob *fileCopyJob = KIO::file_copy(themeURL, tmpUrl, -1, KIO::Overwrite);
+        KIO::CopyJob *fileCopyJob = KIO::copy(themeURL, tmpUrl, KIO::Overwrite);
         if (!fileCopyJob->exec())
         {
             int errorCode = fileCopyJob->error();
